Bcselector
****************************
Python cost-sensitive feature selection library.

.. toctree::
   :glob:
   :maxdepth: 2
   :caption: Contents

   readme
   examples
   api-reference/index
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`